@@ -116,6 +116,13 @@ class BugReport(QDialog):
         self.download_url_lbl.setText(_('Your TortoiseHg is up to date.'))
 
     def gettext(self, opts):
+        def ext_with_ver(x):
+            ext = x[0]
+            ver = extensions.moduleversion(x[1])
+            if ver:
+                ext += b' ' + ver
+            return hglib.tounicode(ext)
+
         # TODO: make this more uniformly unicode safe
         text = '#!python\n' # Bitbucket wiki marker for python code
         text += '** Mercurial version (%s).  TortoiseHg version (%s)\n' % (
@@ -123,7 +130,7 @@ class BugReport(QDialog):
         text += '** Command: %s\n' % (hglib.tounicode(opts.get('cmd', 'N/A')))
         text += '** CWD: %s\n' % hglib.tounicode(_safegetcwd())
         text += '** Encoding: %s\n' % hglib._encoding
-        extlist = [hglib.tounicode(x[0]) for x in extensions.extensions()]
+        extlist = [ext_with_ver(x) for x in sorted(extensions.extensions())]
         text += '** Extensions loaded: %s\n' % ', '.join(extlist)
         text += '** Python version: %s\n' % sys.version.replace('\n', '')
         if os.name == 'nt':
@@ -142,7 +149,8 @@ class BugReport(QDialog):
         QApplication.clipboard().setText(self.text)
 
     def getarch(self):
-        text = '** Windows version: %s\n' % str(sys.getwindowsversion())
+        text = '** Windows version: %s\n' % str(
+            sys.getwindowsversion())  # pytype: disable=module-attr
         arch = 'unknown (failed to import win32api)'
         try:
             import win32api  # pytype: disable=import-error
@@ -247,7 +255,8 @@ class ExceptionMsgBox(QDialog):
                         self.root = os.getcwd()
                         self.ui = hglib.loadui()
                 fake = FakeRepo()
-                qtlib.editfiles(fake, [fname], lineno, parent=self)
+                qtlib.editfiles(fake, [hglib.fromunicode(fname)], int(lineno),
+                                parent=self)
             except Exception as e:
                 qtlib.openlocalurl(fname)
         if ref.startswith('#fix:'):
