@@ -508,11 +508,11 @@ class HooksFrame(QFrame):
 
     def gethooks(self):
         hooks = {}
-        for key, value in self.ini.items('hooks'):
-            keyparts = key.split('.', 1)
+        for key, value in self.ini.items(b'hooks'):
+            keyparts = key.split(b'.', 1)
             hooktype = keyparts[0]
             if len(keyparts) == 1:
-                name = ''
+                name = b''
             else:
                 name = keyparts[1]
             if hooktype not in hooks:
