@@ -51,7 +51,6 @@ from mercurial import (
     pycompat,
     subrepo,
     ui,
-    scmutil,
 )
 from mercurial.utils import (
     stringutil,
@@ -96,12 +95,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
         hbox = QHBoxLayout()
         hbox.setContentsMargins(2, 2, 2, 2)
         le = QLineEdit()
-        if hasattr(le, 'setPlaceholderText'): # Qt >= 4.7
-            le.setPlaceholderText(_('### regular expression search pattern ###'))
-        else:
-            lbl = QLabel(_('Regexp:'))
-            lbl.setBuddy(le)
-            hbox.addWidget(lbl)
+        le.setPlaceholderText(_('### regular expression search pattern ###'))
         chk = QCheckBox(_('Ignore case'))
         bt = QPushButton(_('Search'))
         bt.setDefault(True)
@@ -143,14 +137,8 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
                      'Exclusion patterns are applied after inclusion patterns.')
         ihelpstr = _('Comma separated list of inclusion file patterns. '
                      'By default, the entire repository is searched.')
-        if hasattr(incle, 'setPlaceholderText'): # Qt >= 4.7
-            incle.setPlaceholderText(u' '.join([u'###', ihelpstr, u'###']))
-        else:
-            incle.setToolTip(ihelpstr)
-        if hasattr(excle, 'setPlaceholderText'): # Qt >= 4.7
-            excle.setPlaceholderText(u' '.join([u'###', ehelpstr, u'###']))
-        else:
-            excle.setToolTip(ehelpstr)
+        incle.setPlaceholderText(u' '.join([u'###', ihelpstr, u'###']))
+        excle.setPlaceholderText(u' '.join([u'###', ehelpstr, u'###']))
         grid.addWidget(ilabel, 1, 2)
         grid.addWidget(incle, 1, 3, 1, 2)
         grid.addWidget(elabel, 2, 2)
@@ -343,7 +331,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
             regexp = re.compile(pattern, icase and re.I or 0)
             if self.wholeword.isChecked():
                 # re-compile with whole-word wrapping, we know pattern is safe
-                pattern = r'\b(?:%s)\b' % pattern
+                pattern = br'\b(?:%s)\b' % pattern
                 regexp = re.compile(pattern, icase and re.I or 0)
         except Exception as inst:
             msg = _('grep: invalid match pattern: %s\n') % \
@@ -375,8 +363,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
             self.tv.setColumnHidden(COL_REVISION, True)
             self.tv.setColumnHidden(COL_USER, True)
             try:
-                rev = scmutil.revsymbol(self.repo, revstr or b'.').rev()
-                ctx = self.repo[rev]
+                ctx = hglib.revsymbol(self.repo, revstr or b'.')
             except error.RepoError as e:
                 msg = _('grep: %s\n') % hglib.tounicode(str(e))
                 self.showMessage.emit(msg)
@@ -461,18 +448,19 @@ class HistorySearchThread(QThread):
         def emitprog(topic, pos, item, unit, total):
             self.progress.emit(topic, pos, item, unit, total)
         class incrui(ui.ui):
-            fullmsg = ''
+            fullmsg = b''
             def write(self, msg, *args, **opts):
                 self.fullmsg += msg
-                if self.fullmsg.count('\0') >= 6:
+                if self.fullmsg.count(b'\0') >= 6:
                     try:
                         fname, line, rev, addremove, user, text, tail = \
-                                self.fullmsg.split('\0', 6)
+                                self.fullmsg.split(b'\0', 6)
                         if haslf and thgrepo.isLfStandin(fname):
                             raise ValueError
                         if (haslf or haskbf) and thgrepo.isBfStandin(fname):
                             raise ValueError
                         text = hglib.tounicode(text)
+                        addremove = hglib.tounicode(addremove)
                         text = qtlib.htmlescape(text, False)
                         text = '<b>%s</b> <span>%s</span>' % (addremove, text)
                         fname = hglib.tounicode(fname)
