@@ -28,7 +28,6 @@ from .qtgui import (
 
 from mercurial import (
     error,
-    scmutil,
 )
 
 from ..util import hglib
@@ -233,7 +232,7 @@ class MatchDialog(QDialog):
             self.match_btn.setEnabled(True)
             return
         try:
-            csinfo_update(scmutil.revsymbol(self.repo, new_rev))
+            csinfo_update(hglib.revsymbol(self.repo, new_rev))
             return
         except (error.LookupError, error.RepoLookupError, error.RepoError):
             pass
